@@ -13,6 +13,6 @@
 
 ds_dismeas <- function(fsq, sta, sen){
   save(fsq, sta, sen, file=system.file("extdata/fichier_discalib.RData",package="htsr"))
-  runApp(system.file("extdata/app_dismeas", package="htsr"))
+  runApp(system.file("extdata/app_dismeas", package="htsr"),launch.browser=TRUE)
 }
 
