@@ -21,5 +21,5 @@
 ds_inventory <- function(fsq){
   fsq <- fsq
   save(fsq, file=system.file("extdata/fichier_fsq.RData",package="htsr"))
-  runApp(system.file("extdata/app_invent", package="htsr"))
+  runApp(system.file("extdata/app_invent", package="htsr"),launch.browser=TRUE)
 }
